@@ -267,7 +267,7 @@ class DedupeMatching(Matching) :
 
     def _blockData(self, data_d):
 
-        blocks = defaultdict(set)
+        blocks = defaultdict(dict)
 
         for field in self.blocker.tfidf_fields :
             self.blocker.tfIdfBlock(((record_id, record[field])
@@ -276,11 +276,11 @@ class DedupeMatching(Matching) :
                                     field)
 
         for block_key, record_id in self.blocker(data_d.iteritems()) :
-            blocks[block_key].add((record_id, data_d[record_id]))
+            blocks[block_key][record_id] = data_d[record_id]
 
         self.blocker._resetCanopies()
 
-        blocks = [records for records in blocks.values() 
+        blocks = [records for records in blocks.values()
                   if len(records) > 1]
 
         for block in self._redundantFree(blocks) :
@@ -296,7 +296,7 @@ class DedupeMatching(Matching) :
 
         for block_id, records in enumerate(blocks) :
 
-            for record_id, record in records :
+            for record_id, record in records.iteritems() :
                 coverage[record_id].append(block_id)
 
         for block_id, records in enumerate(blocks) :
@@ -304,7 +304,7 @@ class DedupeMatching(Matching) :
                 logger.info("%s blocks" % block_id)
 
             marked_records = []
-            for record_id, record in records :
+            for record_id, record in records.iteritems() :
                 smaller_ids = set([covered_id for covered_id 
                                    in coverage[record_id] 
                                    if covered_id < block_id])
@@ -595,6 +595,7 @@ class ActiveMatching(Matching) :
             self.activeLearner = training.ActiveLearning(self.data_sample, 
                                                          self.data_model)
         else :
+            self.data_sample = []
             self.activeLearner = None
 
         if num_cores is None :
@@ -767,7 +768,7 @@ class ActiveMatching(Matching) :
                                    'distinct':[]})
 
 
-            self._trainClassifier(alpha=0.1)
+        self._trainClassifier(alpha=0.1)
 
         
         dupe_ratio = (len(self.training_pairs['match'])
@@ -811,8 +812,6 @@ class ActiveMatching(Matching) :
 
         self._addTrainingData(labeled_pairs) 
 
-        self._trainClassifier(alpha=.1)
-
 
 
     def _checkRecordPairType(self, record_pair) :
