@@ -12,7 +12,7 @@ import math
 logger = logging.getLogger(__name__)
 
 class TfIdfIndex(object) :
-    def __init__(self, field, stop_words) :
+    def __init__(self, field, stop_words=[]) :
         self.field = field
  
         splitter = Splitter()
@@ -43,18 +43,17 @@ class TfIdfIndex(object) :
         self._index.unindex_doc(i)
 
     def search(self, doc, threshold=0) :
-        results = self._resultset(doc).byValue(threshold)
-
-        return [self._i_to_id[k] 
-                for  _, k in results]
-
-    def _resultset(self, doc) :
         doc = self._stringify(doc)
         query_list = self._parseTerms(doc)
         query = ' OR '.join(query_list)
 
-        return self._index.apply(query)
+        if query :
+            results = self._index.apply(query).byValue(threshold)
+        else :
+            results = []
 
+        return [self._i_to_id[k] 
+                for  _, k in results]
 
     def _stringify(self, doc) :
         try :
@@ -105,13 +104,13 @@ class CustomStopWordRemover(object):
 
 class OperatorEscaper(object) :
     def __init__(self) :
-        self. operators = {"AND"  : "\AND",
-                           "OR"   : "\OR",
-                           "NOT"  : "\NOT",
-                           "("    : "\(",
-                           ")"    : "\)",
-                           "ATOM" : "\ATOM",
-                           "EOF"  : "\EOF"}
+        self.operators = {"AND"  : "\AND",
+                          "OR"   : "\OR",
+                          "NOT"  : "\NOT",
+                          "("    : "\(",
+                          ")"    : "\)",
+                          "ATOM" : "\ATOM",
+                          "EOF"  : "\EOF"}
 
     def process(self, lst):
         return [self.operators.get(w, w) for w in lst]
